yakumo.neutron.v2.network.Manager

Package yakumo :: Package neutron :: Package v2 :: Module network :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for networks in Networking V2 API

Nested Classes | [hide private]
| resource_class Resource class for networks in Networking V2 API

Instance Methods | [hide private]
yakumo.neutron.v2.network.Resource |
create(self, name=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, is_shared=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`, is_external=`'``__UNDEF__``'`, is_port_security_enabled=`'``__UNDEF__``'`, segments=`'``__UNDEF__``'`, provider_physical_network=`'``__UNDEF__``'`, provider_network_type=`'``__UNDEF__``'`, provider_segmentation_id=`'``__UNDEF__``'`, vlan_transparent=`'``__UNDEF__``'`) Create a network | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``network``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _json_resource_key = ``'``network``'``
| _json_resources_key = ``'``networks``'``
| _url_resource_path = ``'``/v2.0/networks``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_hidden_methods`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, name=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, is_shared=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`, is_external=`'``__UNDEF__``'`, is_port_security_enabled=`'``__UNDEF__``'`, segments=`'``__UNDEF__``'`, provider_physical_network=`'``__UNDEF__``'`, provider_network_type=`'``__UNDEF__``'`, provider_segmentation_id=`'``__UNDEF__``'`, vlan_transparent=`'``__UNDEF__``'`) | source code
Create a network Parameters: `name` (str) - Network name `project` (yakumo.project.Resource) - Project `is_shared` (bool) - Whether the network is shared `is_enabled` (bool) - Whether the network is enabled `is_external` (bool) - Wehter the network is external `is_port_security_enabled` (bool) - Whether the network is secured `segments` (str) - Segments `provider_physical_network` (str) - (Provider) physical network `provider_network_type` (str) - (Provider) network type `provider_segmentation_id` (int) - (Provider) segmentation ID `vlan_transparent` (int) - (Provider) VLAN transparent Returns: yakumo.neutron.v2.network.Resource Created network Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('status',
      'status', mapper.Noop), ('subnets', 'subnets', mapper.List(mapper.Reso
      urce('neutron.subnet'))), ('project', 'tenant_id', mapper.Resource('pr
      oject')), ('is_shared', 'shared', mapper.Noop), ('is_enabled', 'admin_
      state_up', mapper.Noop), ('is_external', 'router:external', mapper.Noo
      p), ('is_secured', 'port_security_enabled', mapper.Noop), ('segments',
       'segments', mapper.Noop), ('provider_physical_network', 'provider:phy
      sical_network', mapper.Noop), ('provider_network_type', 'provider:netw
      ...